@@ -1,27 +1,12 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_CONTACTFETCHJOB_H
-#define LIBKGAPI2_CONTACTFETCHJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapicontacts_export.h"
@@ -177,4 +162,3 @@ class KGAPICONTACTS_EXPORT ContactFetchJob : public KGAPI2::FetchJob
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_CONTACTFETCHJOB_H
