@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI_NETWORKACCESSMANAGERFACTORY_P_H_
-#define KGAPI_NETWORKACCESSMANAGERFACTORY_P_H_
+#pragma once
 
 class QNetworkAccessManager;
 class QObject;
@@ -37,4 +36,3 @@ protected:
 
 }
 
-#endif
