@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVEFILE_H
-#define LIBKGAPI2_DRIVEFILE_H
+#pragma once
 
 #include "object.h"
 #include "types.h"
@@ -667,4 +666,3 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KGAPI2::Drive::File::SerializationOptions)
 
-#endif // LIBKGAPI2_DRIVEFILE_H
